/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Tools.Log.Configuration
{
    using System;
    using System.Configuration;
    using System.Xml;

    /// <summary>
    /// Contains the information for the settings of a DebugAppender
    /// </summary>
    public class DebugAppenderHandler : AppenderHandler, IConfigurationSectionHandler
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="DebugAppenderHandler"/> class.
        /// </summary>
        public DebugAppenderHandler()
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="DebugAppenderHandler"/> class.
        /// </summary>
        /// <param name="isActivated">if set to <c>true</c> [is activated].</param>
        /// <param name="logLevel">The log level.</param>
        private DebugAppenderHandler(bool isActivated, int logLevel)
        {
            this.IsActivated = isActivated;
            this.LogLevel = logLevel;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Creates a configuration section handler.
        /// </summary>
        /// <param name="parent">Parent object.</param>
        /// <param name="configContext">Configuration context object.</param>
        /// <param name="section">Section XML node.</param>
        /// <returns>The created section handler object.</returns>
        public object Create(object parent, object configContext, XmlNode section)
        {
            string isActivatedField = string.Empty;
            string logLevelField = string.Empty;

            try
            {
                isActivatedField = section.SelectSingleNode("Activated").InnerText.ToLower();
                logLevelField = section.SelectSingleNode("LogLevel").InnerText;
            }
            catch (Exception ex)
            {
                string msg = "Impossible to gather the configuration data of the DebugAppender!";
                throw new LoggerConfigurationException(msg, ex);
            }
            base.LogLevel = base.CheckLogLevel(logLevelField);
            base.IsActivated = base.CheckIsActivated(isActivatedField);

            return new DebugAppenderHandler(this.IsActivated, this.LogLevel);
        }

        #endregion Methods
    }
}