/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;
    using System.Collections.Generic;
    using System.Data;
    using System.Data.SQLite;
    using System.Diagnostics;
    using System.Linq;
    using System.Text;

    /// <summary>
    /// Logs into assembly database
    /// </summary>
    public class SQLiteAppender : RootAppender, IAppender
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteAppender"/> class.
        /// </summary>
        /// <param name="persistor">The persistor.</param>
        internal SQLiteAppender(IPersistor persistor)
            : base()
        {
            this.Persistor = persistor;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the persistor.
        /// </summary>
        /// <value>The persistor.</value>
        internal IPersistor Persistor
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Inserts the specified error baseLog.
        /// </summary>
        /// <param name="logRow">The error baseLog.</param>
        protected override void ProcessInsert(IRow logRow)
        {
            if (logRow == null)
                throw new ArgumentException("The argument shouldn't be null!", "logRow");

            if (base.LogLevel < (int)logRow.Stamp)
                return;

            Persistor.LoadStoredProcedure("INSERT_ErrorEntry");
            Persistor.Arguments.Clear();

            string message = (string.IsNullOrEmpty(logRow.Message))
                ? "NULL"
                : string.Format("'{0}'", logRow.Message.Replace("'", "''"));

            string source = (string.IsNullOrEmpty(logRow.Source))
                ? "NULL"
                : string.Format("'{0}'", logRow.Source.Replace("'", "''"));

            string stackTrace = (string.IsNullOrEmpty(logRow.StackTrace))
                ? "NULL"
                : string.Format("'{0}'", logRow.StackTrace.Replace("'", "''"));

            string exceptionMessage = (string.IsNullOrEmpty(logRow.ExceptionMessage))
                ? "NULL"
                : string.Format("'{0}'", logRow.ExceptionMessage.Replace("'", "''"));

            Persistor.Arguments.Add("fk_BaseLog", "'" + GetKey(logRow, true) + "'");
            Persistor.Arguments.Add("Title", string.Format("'{0}'", logRow.Title));
            Persistor.Arguments.Add("Message", message);
            Persistor.Arguments.Add("Source", source);
            Persistor.Arguments.Add("StackTrace", stackTrace);
            Persistor.Arguments.Add("Type", logRow.LogTypeValue.ToString());
            Persistor.Arguments.Add("ID", "'" + GetKey(logRow, false) + "'");
            Persistor.Arguments.Add("ExceptionMessage", exceptionMessage);
            Persistor.Arguments.Add("Deepness", logRow.Deepness.ToString());

            Persistor.ExecuteNonQuery();
        }

        #endregion Methods
    }
}