/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;

    using Phoenix.Log;

    /// <summary>
    /// Factory that creates instances of DBLog
    /// </summary>
    public sealed class SQLiteAppenderFactory : IAppenderFactory
    {
        #region Fields

        private static SQLiteAppender appender;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteAppenderFactory"/> class.
        /// </summary>
        public SQLiteAppenderFactory()
        {
            InitInstance(new SQLitePersistor());
        }

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteAppenderFactory"/> class.
        /// </summary>
        /// <param name="persistor">The persistor of the appender.</param>
        /// <remarks>This constructir exists for testing purpose.</remarks>
        [Obsolete("Use the default constructor! This one is for testing purpose.")]
        public SQLiteAppenderFactory(IPersistor persistor)
        {
            InitInstance(persistor);
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets an instance of assembly log class.
        /// </summary>
        /// <param name="senderType">Type of the sender. </param>
        /// <returns>A instance of assembly appender</returns>
        public IAppender GetAppender(System.Type senderType)
        {
            appender.SetTypeOfSender(senderType);
            return appender;
        }

        /// <summary>
        /// Initialise the instance.
        /// </summary>
        /// <param name="persistor">The persistor.</param>
        private static void InitInstance(IPersistor persistor)
        {
            if (appender == null)
            {
                appender = new SQLiteAppender(persistor);
            }
            else
            {
                appender.Persistor = persistor;
            }
        }

        #endregion Methods
    }
}