/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Tools.Translation
{
    using System.Collections.Generic;

    #region Enumerations

    /// <summary>
    /// The languages supported for translation
    /// </summary>
    public enum Language
    {
        /// <summary>
        /// FRENCH
        /// </summary>
        FR,
        /// <summary>
        /// ENGLISH
        /// </summary>
        EN,
        /// <summary>
        /// SPANISH
        /// </summary>
        ES,
    }

    #endregion Enumerations

    /// <summary>
    /// Provides features to get the translation from the repository.
    /// </summary>
    public interface IRepository
    {
        #region Methods

        /// <summary>
        /// Gets the count of translation stored in the repository.
        /// </summary>
        /// <value>The count.</value>
        long CalculateCount();

        /// <summary>
        /// Determines whether the specified key exist in the repository
        /// </summary>
        /// <param name="keyToCheck">The key to check.</param>
        /// <returns>
        /// 	<c>true</c> if the specified key exist in the repository. Otherwise <b>false</b>
        /// </returns>
        bool ExistInRepository(string keyToCheck);

        /// <summary>
        /// Gets the translations from the translation repository.
        /// </summary>
        /// <returns>A dictionary list of the text and its translation.</returns>
        Dictionary<string, string> GetTranslations();

        /// <summary>
        /// Inserts the new phrase into the database.
        /// By default the database assumes this phrase is in english
        /// and stores that into the english language.
        /// </summary>
        /// <param name="phrase">The phrase.</param>
        void InsertNewPhrase(string phrase);

        /// <summary>
        /// Sets the languageToSet for the translation.
        /// Change the languageToSet does NOT refresh the translation. To be up to date, the
        /// call of GetTranslation is mandatory!
        /// </summary>
        /// <param name="languageToSet">The translation will be on this specified languageToSet.</param>
        void SetLanguage(Language language);

        #endregion Methods
    }
}